aboutsummaryrefslogtreecommitdiff
path: root/src/modules/m_spanningtree/uid.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/modules/m_spanningtree/uid.cpp')
-rw-r--r--src/modules/m_spanningtree/uid.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/modules/m_spanningtree/uid.cpp b/src/modules/m_spanningtree/uid.cpp
index ccedf8c3c..e141f022b 100644
--- a/src/modules/m_spanningtree/uid.cpp
+++ b/src/modules/m_spanningtree/uid.cpp
@@ -51,14 +51,14 @@ CmdResult CommandUID::HandleServer(TreeServer* remoteserver, CommandBase::Params
auto collideswith = ServerInstance->Users.FindNick(params[2]);
if (collideswith && !collideswith->IsFullyConnected())
{
// User that the incoming user is colliding with is not fully registered, we force nick change the
// unregistered user to their uuid and tell them what happened
LocalUser* const localuser = static_cast<LocalUser*>(collideswith);
localuser->OverruleNick();
}
else if (collideswith)
{
// The user on this side is registered, handle the collision
bool they_change = Utils->DoCollision(collideswith, remoteserver, nickchanged, params[5], params[6], params[0], "UID");
if (they_change)
{
@@ -85,7 +85,7 @@ CmdResult CommandUID::HandleServer(TreeServer* remoteserver, CommandBase::Params
_new->ident = params[5];
_new->ChangeRemoteAddress(sa);
_new->ChangeRealName(params.back());
- _new->registered = REG_ALL;
+ _new->connected = User::CONN_FULL;
_new->signon = signon;
_new->nickchanged = nickchanged;
@@ -51,14 +51,14 @@ CmdResult CommandUID::HandleServer(TreeServer* remoteserver, CommandBase::Params
if (collideswith && !collideswith->IsFullyConnected())
{
- // User that the incoming user is colliding with is not fully registered, we force nick change the
- // unregistered user to their uuid and tell them what happened
+ // User that the incoming user is colliding with is not fully connected, we force nick change the
+ // partially connected user to their uuid and tell them what happened
LocalUser* const localuser = static_cast<LocalUser*>(collideswith);
localuser->OverruleNick();
@@ -51,14 +51,14 @@ CmdResult CommandUID::HandleServer(TreeServer* remoteserver, CommandBase::Params
else if (collideswith)
{
- // The user on this side is registered, handle the collision
+ // The user on this side is fully connected, handle the collision
bool they_change = Utils->DoCollision(collideswith, remoteserver, nickchanged, params[5], params[6], params[0], "UID");
if (they_change)